;**************************************************************************
;* FileName	: DUMMY675.ASM
;* Date 	: 14.05.2007
;* File version : v1.00
								list l=0
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.atw.hu
;* E-mail	: majki.mester@gmail.com
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Dummy test
;*		  ==================================
;*		  Dummy test code.
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       ________	  ________
;*			      |        \_/	  |
;*			+5V ==| Vdd	      Vss |== GND
;*		       n.c. ==| GP5/OSC1      GP0 |== n.c.
;*		       n.c. ==| GP4/OSC2      GP1 |== n.c.
;*		       n.c. ==| GP3/-MCLR     GP2 |== n.c.
;*			      |___________________|
;*				    PIC12F675
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /    6 pin   (   %)
;*		  Data memory	  :    xx /   64 byte  (   %)
;*		  Prog memory	  :   xxx / 1024 word  (   %)
;*		  EEPROM	  :    xx /  128 byte  (   %)
;*		  Timers	  : 
;*		  Interrupt	  : 
;*		  Comparator	  :
;*		  AD              :
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  14/05/2007 	Initial Release
;*
;**************************************************************************

	list	p=12f675, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p12f675.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

CFG_1	EQU 	_INTRC_OSC_NOCLKOUT & _WDT_OFF & _PWRTE_ON & _MCLRE_OFF
CFG_2	EQU	_BODEN_ON & _CP_OFF & _CPD_OFF
CFG_3   EQU     01000111111111b			; unimplemented bits + BG0-BG1


	__CONFIG CFG_1 & CFG_2 & CFG_3
	__IDLOCS 0100h				; version

	EXPAND_MACROS	EXP_COND		; macro expansion mode
	MULTIPAGE	1, 2048, 2		; support for multipage program memory

;***** DEFINES ************************************************************
;#define DEBUG					; for some debug message
;#define NO_DELAY				; for fast simulation
;#define NO_RS232				; for fast simulation

xtal_freq	EQU	4 MHz	  		; crystal frequency
core_freq	EQU	xtal_freq/4		; core operating frequency


; ----- GPIO --------------------------------------------------------------

#define		GPIO_0		GPIO,0		; free
#define		GPIO_1		GPIO,1		; free
#define		GPIO_2		GPIO,2		; free
#define		GPIO_3		GPIO,3		; free (only input or -MCLR!)
#define		GPIO_4		GPIO,4		; free (IO or OSC2)
#define		GPIO_5		GPIO,5		; free (IO or OSC1)

; ----- module defines ----------------------------------------------------

#define	AD_WITH_ANSEL				; device with ANSEL register


;***** MACROS *************************************************************

	include "..\..\modules\dummy.mac"


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	10000010b		; Timer source : intclk / 8
tris_val	EQU	00111111b		; tris value (all input)
ansel_val       EQU     00000000b		; all input is digital
wpu_val         EQU     00000000b		; weak pull ups all off
intcon_val	EQU	00100000b		; Interrupt off
cmcon_val	EQU	00000111b		; comparators off


;***** VARIABLE DEFINITIONS ***********************************************
	cblock	20h
		w_temp				; variable used for context saving
		status_temp			; variable used for context saving
		fsr_temp			; variable used for context saving

		TEMP				; dummy register

	endc




;***** ENTRY POINT ********************************************************
		ORG	000h			; processor reset vector
		nop
		clrf	GPIO			; clear latch
		clrwdt
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h			; interrupt vector location
		movwf	w_temp			; save off current W register contents
		movf	STATUS,w		; move STATUS register into W register
		movwf	status_temp		; save off contents of STATUS register

		movf	FSR,w			; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		clrf	STATUS			; bank 0

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w		; restore FSR
		movwf	FSR

		movf	status_temp,w		; retrieve copy of STATUS register
		movwf	STATUS			; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w		; restore pre-isr W register contents
		retfie				; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		bank1
		movwf	LL OSCCAL		; store OSCCAL value
		movlw	option_val
		movwf	LL OPTION_REG		; set OPTION_REG
		movlw	tris_val
		movwf	LL TRISIO		; set TRISIO
		movlw	ansel_val	
		movwf	LL ANSEL		; set ANSEL
		movlw	wpu_val	
		ERRORLEVEL -302
		movwf	WPU			; set WPU
		ERRORLEVEL +302

		bank0
		movlw	intcon_val	
		movwf	INTCON			; set INTCON
		movlw	cmcon_val	
		movwf	CMCON			; set CMCON






;----- main cycle  --------------------------------------------------------


main_cycle	nop

		; <code>

		goto	main_cycle






;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************

sub1 


		return

;***** INCLUDES ***********************************************************

	include "..\..\modules\dummy.inc"


;**************************************************************************
	end				  	; end of program








