;**************************************************************************
;* FileName	: DUMMY628.ASM
;* Date 	: 25.08.2005
;* File version : v1.00
								list l=0
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.atw.hu
;* E-mail	: majki.mester@gmail.com
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Dummy test
;*		  ==================================
;*		  Dummy test code.
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       ________	  ________
;*			      |        \_/	  |
;*		       n.c. ==| RA2	      RA1 |== n.c.
;*		       n.c. ==| RA3	      RA0 |== n.c.
;*		       n.c. ==| RA4      RA7/OSC1 |== quartz1
;*		     -reset ==|-MCLR/RA5 RA6/OSC2 |== quartz2
;*			GND ==| Vss	      Vdd |== +5V
;*		       n.c. ==| RB0	      RB7 |== n.c.
;*		       n.c. ==| RB1	      RB6 |== n.c.
;*		       n.c. ==| RB2	      RB5 |== n.c.
;*		       n.c. ==| RB3	      RB4 |== n.c.
;*			      |___________________|
;*				    PIC16F628
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   15 pin   (   %)
;*		  Data memory	  :    xx /  224 byte  (   %)
;*		  Prog memory	  :   xxx / 2048 word  (   %)
;*		  EEPROM	  :    xx /  128 byte  (   %)
;*		  Timers	  : 
;*		  Interrupt	  : 
;*		  CCP		  :
;*		  USART		  :
;*		  Comparator	  :
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  25/08/2005 	Initial Release
;*
;**************************************************************************

	list	p=16f628, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f628.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

CFG_1	EQU 	_XT_OSC & _WDT_OFF & _PWRTE_ON & _MCLRE_ON & _BODEN_ON
CFG_2	EQU	_LVP_OFF & _CP_OFF


	__CONFIG CFG_1 & CFG_2
	__IDLOCS 0100h				; version

	EXPAND_MACROS	EXP_COND		; macro expansion mode
	MULTIPAGE	1, 2048, 4		; support for multipage program memory

;***** DEFINES ************************************************************
;#define DEBUG					; for some debug message
;#define NO_DELAY				; for fast simulation
;#define NO_RS232				; for fast simulation

xtal_freq	EQU	4 MHz	  		; crystal frequency
core_freq	EQU	xtal_freq/4		; core operating frequency


; ----- porta -------------------------------------------------------------

#define		PORTA_0		PORTA,0		; free
#define		PORTA_1		PORTA,1		; free
#define		PORTA_2		PORTA,2		; free
#define		PORTA_3		PORTA,3		; free
#define		PORTA_4		PORTA,4		; free (open drain)
#define		PORTA_5		PORTA,5		; free (only input or -MCLR!)
#define		PORTA_6		PORTA,6		; free (or OSC2)
#define		PORTA_7		PORTA,7		; free (or OSC1)

; ----- portb -------------------------------------------------------------

#define		PORTB_0		PORTB,0		; free
#define		PORTB_1		PORTB,1		; free
#define		PORTB_2		PORTB,2		; free
#define		PORTB_3		PORTB,3		; free
#define		PORTB_4		PORTB,4		; free
#define		PORTB_5		PORTB,5		; free
#define		PORTB_6		PORTB,6		; free
#define		PORTB_7		PORTB,7		; free



;***** MACROS *************************************************************

	include "..\..\modules\dummy.mac"


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	10000010b		; Timer source : intclk / 8
trisa_val	EQU	11111111b		; TRISA value (all input)
trisb_val	EQU	11111111b		; TRISB value (all input)
intcon_val	EQU	00100000b		; Interrupt control
cmcon_val	EQU	00000111b		; comparators off


;***** VARIABLE DEFINITIONS ***********************************************
	cblock	70h				; common RAM
		w_temp				; variable used for context saving
		status_temp			; variable used for context saving
		fsr_temp			; variable used for context saving
	endc

;--------------------------------------------------------------------------
	cblock	20h

		TEMP				; dummy register

	endc




;***** ENTRY POINT ********************************************************
		ORG	000h			; processor reset vector
		nop
		clrwdt
		clrf	STATUS
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h			; interrupt vector location
		movwf	w_temp			; save off current W register contents
		movf	STATUS,w		; move STATUS register into W register
		movwf	status_temp		; save off contents of STATUS register

		movf	FSR,w			; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		clrf	STATUS			; bank 0

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w		; restore FSR
		movwf	FSR

		movf	status_temp,w		; retrieve copy of STATUS register
		movwf	STATUS			; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w		; restore pre-isr W register contents
		retfie				; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		clrf	PORTA			; clear latch
		clrf	PORTB			; clear latch

		bank1
		movlw	option_val
		movwf	LL OPTION_REG		; set OPTION_REG
		movlw	trisa_val
		movwf	LL TRISA		; set TRISA
		movlw	trisb_val
		movwf	LL TRISB		; set TRISB

		bank0
		movlw	intcon_val	
		movwf	INTCON			; set INTCON
		movlw	cmcon_val	
		movwf	CMCON			; set CMCOM


;----- main cycle  --------------------------------------------------------


main_cycle	nop

		; <code>

		goto	main_cycle






;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************

sub1 


		return

;***** INCLUDES ***********************************************************

	include "..\..\modules\dummy.inc"


;**************************************************************************
	end				  	; end of program








