;**************************************************************************
;* FileName	: 16F684.ASM
;* Date		: 05.09.2008
;* File version	: v1.00
;*
;* Author	: Szraz, Attila
;* Company	:
;* Homepage	:
;* E-mail	: djdry@freemail.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	:
;*            
;*		 ==================================
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:          ________   ________
;*                        |        \_/        |
;*                  +5V ==| Vdd           Vss |== GND
;*                 n.c. ==| RA5/OSC1      RA0 |== n.c.
;*                 n.c. ==| RA4/OSC2      RA1 |== n.c.
;*                 n.c. ==|-MCLR/RA3      RA2 |== n.c.
;*                 n.c. ==| RC5           RC0 |== n.c.
;*                 n.c. ==| RC4           RC1 |== n.c.
;*                 n.c. ==| RC3           RC2 |== n.c.
;*                        |___________________|
;*                            PIC16F688
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports		:    xx /   12 pin   (   %)
;*		  Data memory	:    xx /  256 byte  (   %)
;*		  Prog memory	:   xxx / 4096 word  (   %)
;*		  EEPROM	:    xx /  256 byte  (   %)
;*		  Timers	:     2 /    1
;*		  Interrupt	:
;*		  CCP		:
;*		  USART		:
;*		  Comparator	: 2
;*
;**************************************************************************
;* Revision History:
;*
;*
;*
;**************************************************************************

    list    p=16f688, r=dec, l=0

;***** INCLUDES ***********************************************************

    include "p16f688.inc"
    include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

CFG_1    EQU     _INTRC_OSC_NOCLKOUT & _WDT_OFF & _PWRTE_ON & _MCLRE_OFF & _CP_ON & _CPD_ON

    __CONFIG CFG_1
    __IDLOCS 0100h                ; version

    EXPAND_MACROS    EXP_COND    ; macro expansion mode
    MULTIPAGE    1, 2048, 4        ; support for multipage program memory

;***** DEFINES ************************************************************
;#define DEBUG                    ; for some debug message
;#define NO_DELAY                ; for fast simulation
;#define NO_RS232                ; for fast simulation

xtal_freq    EQU    4 MHz              ; crystal frequency
core_freq    EQU    xtal_freq/4        ; core operating frequency

; ----- porta -------------------------------------------------------------

#define        PORTA_0            PORTA,0        ; free
#define        PORTA_1            PORTA,1        ; free
#define        PORTA_2            PORTA,2        ; free
#define        PORTA_3            PORTA,3        ; free (only input or -MCLR!)
#define        PORTA_4            PORTA,4        ; free (or OSC2)
#define        PORTA_5            PORTA,5        ; free (or OSC1)

; ----- portc -------------------------------------------------------------

#define        PORTC_0            PORTC,0        ; free
#define        PORTC_1            PORTC,1        ; free
#define        PORTC_2            PORTC,2        ; free
#define        PORTC_3            PORTC,3        ; free
#define        PORTC_4            PORTC,4        ; free
#define        PORTC_5            PORTC,5        ; free

;***** MACROS *************************************************************

;    include "..\..\modules\wait.mac"


;***** CONSTANT DEFINITIONS ***********************************************

option_val    EQU    00000010b        ; Timer source : intclk / 8
trisa_val    EQU    00111111b        ; TRISA value
trisc_val    EQU    00111111b        ; TRISC value
intcon_val    EQU    00000000b        ; Interrupt control
wpua_val    EQU    00000000b        ; Weak pull-up
cmcon_val    EQU    00000111b        ; comparators off



;***** VARIABLE DEFINITIONS ***********************************************
    cblock    70h                ; common RAM
        w_temp                ; variable used for context saving
        status_temp            ; variable used for context saving
        fsr_temp            ; variable used for context saving
    endc
;--------------------------------------------------------------------------
    cblock    20h

        Adat

    endc
;***** ENTRY POINT ********************************************************
        ORG    000h            ; processor reset vector
        nop
        clrwdt
        clrf    STATUS
        goto    start

;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
        ORG    004h                ; interrupt vector location
        movwf    w_temp            ; save off current W register contents
        movf    STATUS,w        ; move STATUS register into W register
        movwf    status_temp        ; save off contents of STATUS register

        movf    FSR,w            ; save FSR
        movwf    fsr_temp
;--------------------------------------------------------------------------

        clrf    STATUS            ; bank 0
        ; <IT Code>

;--------------------------------------------------------------------------
        movf    fsr_temp,w        ; restore FSR
        movwf    FSR

        movf    status_temp,w    ; retrieve copy of STATUS register
        movwf    STATUS            ; restore pre-isr STATUS register contents
        swapf    w_temp,f
        swapf    w_temp,w        ; restore pre-isr W register contents
        retfie                    ; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
        clrf    PORTA            ; clear latch
        clrf    PORTC            ; clear latch

        bank1
        movlw    option_val
        movwf    OPTION_REG        ; set OPTION_REG
        movlw    trisa_val
        movwf    TRISA            ; set TRISA
        movlw    trisc_val
        movwf    TRISC            ; set TRISC
        movlw    wpua_val
        movwf    WPUA            ; set Pull-up
        Clrf    ANSEL

        bank0
        movlw    intcon_val    
        movwf    INTCON            ; set INTCON
        movlw    cmcon_val    
        movwf    CMCON0            ; set CMCOM

;----- inits ----------------------------------------------------------



;----- Sajt ciklus  --------------------------------------------------
Main:





;***** INCLUDES *******************************************************

;    include "..\..\modules\wait.inc"

;**********************************************************************
    end                  ; Program vege
