;**************************************************************************
;* FileName	: DUMMY690.ASM
;* Date 	: 17.12.2010
;* File version : v1.00
								list l=0
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.atw.hu
;* E-mail	: majki.mester@gmail.com
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Dummy test
;*		  ==================================
;*		  Dummy test code.
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       ________	  ________
;*			      |        \_/	  |
;*		       n.c. ==| RA2	      RA1 |== n.c.
;*		       n.c. ==| RA3	      RA0 |== n.c.
;*		       n.c. ==| RA4      RA7/OSC1 |== quartz1
;*		     -reset ==|-MCLR/RA5 RA6/OSC2 |== quartz2
;*			GND ==| Vss	      Vdd |== +5V
;*		       n.c. ==| RB0	      RB7 |== n.c.
;*		       n.c. ==| RB1	      RB6 |== n.c.
;*		       n.c. ==| RB2	      RB5 |== n.c.
;*		       n.c. ==| RB3	      RB4 |== n.c.
;*			      |___________________|
;*				    PIC16F690
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   18 pin   (   %)
;*		  Data memory	  :    xx /  256 byte  (   %)
;*		  Prog memory	  :   xxx / 4096 word  (   %)
;*		  EEPROM	  :    xx /  256 byte  (   %)
;*		  Timers	  : 
;*		  Interrupt	  : 
;*		  SSP		  :
;*		  ECCP		  :
;*		  EUSART	  :
;*		  Comparator	  :
;*		  ADC		  :
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  17/12/2010 	Initial Release
;*
;**************************************************************************

	list	p=16f690, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f690.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

CFG_1	EQU 	_INTOSCIO & _WDT_OFF & _PWRTE_ON & _MCLRE_ON & _CP_OFF
CFG_2	EQU	_CPD_OFF & _BOR_OFF & _IESO_OFF & _FCMEN_OFF


	__CONFIG CFG_1 & CFG_2
	__IDLOCS 0100h				; version

	EXPAND_MACROS	EXP_COND		; macro expansion mode
	MULTIPAGE	2, 2048, 4		; support for multipage program memory

;***** DEFINES ************************************************************
;#define DEBUG					; for some debug message
;#define NO_DELAY				; for fast simulation
;#define NO_RS232				; for fast simulation

xtal_freq	EQU	4 MHz	  		; crystal frequency
core_freq	EQU	xtal_freq/4		; core operating frequency


; ----- porta -------------------------------------------------------------

#define		PORTA_0		PORTA,0		; free (ICSPDAT)
#define		PORTA_1		PORTA,1		; free (ICSPCLK)
#define		PORTA_2		PORTA,2		; free
#define		PORTA_3		PORTA,3		; free (only input or -MCLR!)
#define		PORTA_4		PORTA,4		; free (or OSC2)
#define		PORTA_5		PORTA,5		; free (or OSC1)

; ----- portb -------------------------------------------------------------

#define		PORTB_4		PORTB,4		; free
#define		PORTB_5		PORTB,5		; free
#define		PORTB_6		PORTB,6		; free
#define		PORTB_7		PORTB,7		; free

; ----- portc -------------------------------------------------------------

#define		PORTC_0		PORTC,0		; free
#define		PORTC_1		PORTC,1		; free
#define		PORTC_2		PORTC,2		; free
#define		PORTC_3		PORTC,3		; free
#define		PORTC_4		PORTC,4		; free
#define		PORTC_5		PORTC,5		; free
#define		PORTC_6		PORTC,6		; free
#define		PORTC_7		PORTC,7		; free


;***** MACROS *************************************************************

	include "..\..\modules\dummy.mac"


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	00000010b		; Timer source : intclk / 8
trisa_val	EQU	11111111b		; TRISA value (all input)
trisb_val	EQU	11111111b		; TRISB value (all input)
trisc_val	EQU	11111111b		; TRISB value (all input)
wpua_val	EQU	00000000b		; Weak pull-up for PORTA
wpub_val	EQU	00000000b		; Weak pull-up for PORTB
intcon_val	EQU	00100000b		; Interrupt control
ansel_val	EQU	00000000b		; analog input off
anselh_val	EQU	00000000b		; analog input off


;***** VARIABLE DEFINITIONS ***********************************************
	cblock	70h				; common RAM
		w_temp				; variable used for context saving
		status_temp			; variable used for context saving
		fsr_temp			; variable used for context saving
	endc

;--------------------------------------------------------------------------
	cblock	20h

		TEMP				; dummy register

	endc



;##########################################################################
;# PAGE 0
;##########################################################################


;***** ENTRY POINT ********************************************************
		ORG	000h			; processor reset vector
		nop
		clrwdt
		clrf	STATUS
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h			; interrupt vector location
		movwf	w_temp			; save off current W register contents
		movf	STATUS,w		; move STATUS register into W register
		movwf	status_temp		; save off contents of STATUS register

		movf	FSR,w			; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		clrf	STATUS			; bank 0

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w		; restore FSR
		movwf	FSR

		movf	status_temp,w		; retrieve copy of STATUS register
		movwf	STATUS			; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w		; restore pre-isr W register contents
		retfie				; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		clrf	PORTA			; clear latch
		clrf	PORTB			; clear latch
		clrf	PORTC			; clear latch

		bank1
		movlw	option_val
		movwf	LL OPTION_REG		; set OPTION_REG
		movlw	trisa_val
		movwf	LL TRISA		; set TRISA
		movlw	trisb_val
		movwf	LL TRISB		; set TRISB
		movlw	trisc_val
		movwf	LL TRISC		; set TRISC
		movlw	wpua_val
		movwf	WPUA			; set PORTA Pull-up

		bank0
		movlw	intcon_val	
		movwf	INTCON			; set INTCON

		bankhi
		movlw	wpub_val
		movwf	WPUB			; set PORTB Pull-up
		movlw	ansel_val
		movwf	ANSEL			; analog input configuration
		movlw	anselh_val
		movwf	ANSELH			; analog input configuration H
		banklo


;----- main cycle  --------------------------------------------------------


main_cycle	nop

		; <code>

		pagesel	sub_0 
		call	sub_0

		pagesel	sub_1
		call	sub_1

		goto	main_cycle




;***** sub_0 **************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************
sub_0		return



;***** PAGE 0 INCLUDES ****************************************************

	include "..\..\modules\dummy.inc"

;************************************************************************** 






;##########################################################################
;# PAGE 1
;##########################################################################

		ORG	0800h


;***** sub_1 **************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************
sub_1		return



;***** PAGE 1 INCLUDES ****************************************************

	; include "..\..\modules\dummy.inc"

;**************************************************************************




	end				  	; end of program








